:mod:`djangoflash.models` --- Django-flash model
================================================

.. automodule:: djangoflash.models
   :synopsis: Django-flash model


:class:`FlashScope` Objects
```````````````````````````

.. autoclass:: FlashScope
   :show-inheritance:
   :members:


.. seealso::
   :ref:`modulesindex`

